import * as asyncStorageUtils from 'react-native-async-storage-utils';
import { UploadEntriesFunction } from './types';
export declare const ASYNC_STORAGE_KEY = "com.primlo.nibbana.logEntries";
export interface ConfigureProps {
    endpoint: string;
    nibbanaToken: string;
    capacity?: number;
    additionalHTTPHeaders?: () => any;
    asyncStorage?: asyncStorageUtils.IAsyncStorage;
    outputToConsole?: boolean;
}
export declare const configure: (props: ConfigureProps) => void;
export interface ConfigureWithCustomUploadFunctionProps {
    uploadEntries: UploadEntriesFunction;
    capacity?: number;
    asyncStorage?: asyncStorageUtils.IAsyncStorage;
    outputToConsole?: boolean;
}
export declare const configureWithCustomUploadFunction: (props: ConfigureWithCustomUploadFunctionProps) => void;
/**
 * Sets your super properties. Super properties get saved with every entry.
 * @param newSuperProperties The new super properties
 */
export declare const setSuperProperties: (newSuperProperties: object) => void;
/**
 * Extends your existing super properties
 * @param additionalSuperProperties An object to be merged into your super properties
 */
export declare const extendSuperProperties: (additionalSuperProperties: object) => any;
/**
 * Resets all super properties
 */
export declare const clearSuperProperties: () => void;
/**
 * Clears all locally saved log entries.
 */
export declare const clearEntries: () => Promise<void>;
/**
 * Use this instead of console.log.
 * @param data What to log. Can be a string or an Error.
 */
export declare const log: (...data: any[]) => Promise<void>;
/**
 * Use this instead of console.warn.
 * @param data What to log. Can be a string or an Error.
 */
export declare const warn: (...data: any[]) => Promise<void>;
/**
 * Use this instead of console.debug.
 * @param data What to log. Can be a string or an Error.
 */
export declare const debug: (...data: any[]) => Promise<void>;
/**
 * Use this instead of console.error.
 * @param data What to log. Can be a string or an Error.
 */
export declare const error: (...data: any[]) => Promise<void>;
/**
 * This forces an upload of all locally saved log entries
 */
export declare const uploadNow: () => Promise<void>;
/**
 * This starts periodic uploads of locally saved entries in the background
 * @param frequencyInSeconds The upload frequency in seconds. Don't set this to a value too low.
 */
export declare const startAutomaticUploads: (frequencyInSeconds?: number) => void;
/**
 * This stops periodic background uploads
 */
export declare const stopAutomaticUploads: () => void;
